% Boundcing Ball Animation Demonstration
% Bob Woodward, IRIS for the USArray Data Processing Workshop

clear
%
% set movie characteristics
%
vidHeight = 400;
vidWidth  = 300;
aviobj = VideoWriter('my_bouncing_ball');
aviobj.FrameRate = 15;
aviobj.Quality = 100;
open(aviobj)
F(1:101) = ...
    struct('cdata', zeros(vidHeight, vidWidth, 3, 'uint8'),...
    'colormap', []); % pre-allocate memory, for speed
%
% open figure, using movie characteristics from above
%
figure('Position',[1 100 vidWidth vidHeight],'Color','white');
hold on
xlim ([-1 1]);
ylim ([-1 3]);
%
% plot static part of image
%
plot([-.5 .5],[0 0]); % plot a little blue line for the ball to bounce on
title('Bouncing Ball Movie')
ylabel('height');
%
% loop over frames of movie, plotting the bouncing ball
%
k = 0;
for t=0.0 : 5.0 : 500.0
    amp = cos(2*pi*0.01*t) + 1;
    h   = scatter(0,amp,100,[1 amp/2 amp/2],'filled','markeredgecolor','k');
    %     pause(0.1);
    k = k + 1;
    F(k) = getframe(gcf);
    writeVideo(aviobj,F(k)); % write just one frame at a time
    delete(h)    % use object graphics to delete the ball
end
%
% Alternative write strategy - write out entire set of frames in one call
%
%writeVideo(aviobj,F(1:k));
close(aviobj);

% View the movie in matlab using
% movie(F);
%
